@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # -*- Mode: Python -*-
-# vi:si:ai:et:sw=4:sts=4:ts=4
+# vim:si:ai:et:sw=4:sts=4:ts=4
 #
-# Copyright Nicolas Bertrand (nico@inattendu.org), 2009
+# Copyright Nicolas Bertrand (nico@inattendu.org), 2009-2010
 #
 # This file is part of Luciole.
 #
@@ -77,16 +77,18 @@ class Page_intro(gtk.VBox) :
                                 )
         
         # Use a gtk.table to display project/folder chosse  
-        table = gtk.Table(2, 2, True)
+        table = gtk.Table(3, 2, True)
         
         label_project_name = gtk.Label(_('Project Name'))
         # positionning of label
         label_project_name.set_alignment(xalign=0.0,yalign=0.5)    # left justification of label
+    
         # Insert label into the upper left quadrant of the table
         table.attach(label_project_name, 0, 1, 0, 1,xpadding = 10 )
         
         self.entry_project_name = gtk.Entry()
-        self.entry_project_name.connect('changed',self.project_name_changed)
+        self.entry_project_name.set_text('')
+        self.entry_project_name.connect('changed',self.on_project_name_changed)
         # Insert entry_project_name into the upper right quadrant of the table
         table.attach(self.entry_project_name, 1, 2, 0, 1, xpadding =10)
         
@@ -104,10 +106,19 @@ class Page_intro(gtk.VBox) :
                                             gtk.STOCK_OK,gtk.RESPONSE_OK)
                                         )
         self.fileChooser = gtk.FileChooserButton(dialog)
+        self.fileChooser.connect('selection-changed',self.on_dir_is_changed) 
+
         self.fileChooser.set_current_folder(os.path.expandvars('$HOME'))
+        self.fileChooser.set_filename(os.path.expandvars('$HOME'))
         # Insert label into the lower right quadrant of the table
         table.attach(self.fileChooser, 1, 2, 1, 2, yoptions=gtk.SHRINK, xpadding =10)
-        
+       
+        #label for message
+        self.message_label =  gtk.Label('')
+        self.message_label.set_alignment(xalign=0.0,yalign=0.5)            # left justification of label
+        table.attach(self.message_label,0,2,2,3,yoptions=gtk.FILL,xpadding=10)
+
+
         # pack table to main widget
         self.pack_start(    child = table,
                             expand = True,
@@ -116,56 +127,68 @@ class Page_intro(gtk.VBox) :
                                 )
                   
             
-    def project_name_changed(self,widget):
-        """ indicate project name change. Set page complete if non blank text is set."""
-        if widget.get_text() == "" :
-            self.assistant.set_page_complete(self,False)
-        else :
-            l_project_name = widget.get_text()
-            if self.pattern_filename.match(l_project_name) :
-                self.assistant.set_page_complete(self,True)
-            else :
-                self.assistant.set_page_complete(self,False)
-             
-    def verify_page(self, assistant):
-        """ Verify if datas in page 1 are OK and save valid data 
-            Check if project name is alhpanumeric 
-            Check if project already exist.
-        """
-        l_state = False
-        # check if page is coplete
-        if ( assistant.get_page_complete(self) ) :
-           
-            # Verify that a project name is entered anc correct
-            l_project_name = self.entry_project_name.get_text()
-            if self.pattern_filename.match(l_project_name) :
-                # format is correct 
-                self.project_data['project_name'] = l_project_name 
-                l_state = True 
-            else :
-                l_state = False
-                msg = _("%s is not valid. Not valid project name. It should be a combination of alphanumeric and '_' characters "%l_project_name) 
-                #GMSG.Dialog.ErrorMessage(assistant,msg)
-                print msg
-            if  (l_state==True) : 
-                # get project dir
-                self.project_data['project_dir'] = self.fileChooser.get_filename()
-
-                # verify if project exists
-                if (os.path.exists(os.path.join(self.project_data['project_dir'],  self.project_data['project_name']))) :
-                    # directory exists
-                    l_state = False
-                    msg = _("The project already %s exists !"%(os.path.join(self.project_data['project_dir'],  
-                                                                         self.project_data['project_name'])))
-                    GMSG.Dialog.ErrorMessage (assistant,msg)
-        else :
-            # page not complete
-            l_state =False
-        return l_state
+       
+    def _isProjectExists(self, project_path) :
+        """ Check if a project path exists"""
+        return os.path.exists(project_path)
     
-    def set_entry_project_name(self, text):
-        """ function set texte on project name entry """
-        self.entry_project_name.set_text(text)
+    def _isProjectNameValid(self, name) :
+        """ Check ig entered project name is correct"""
+        isValid = False
+        if self.pattern_filename.match(name) :
+            isValid = True
+        return isValid
+         
+
+    def UpdateProjectData(self,project_name, project_folder)  :
+        """ Update project data like 'project_name' and 'project_fir'.
+            projetct dict. is updated if the project project_name is correct
+            and if path project_dir/project_name doe not exists yet.
+            Return True if project has been updated"""
+
+        isProjectUpdated = False
+        # get project name and dir
+        self.message_label.set_text(' ')
+        self.assistant.set_page_complete(self,False)
+        # verify if input date are not balnk
+        if project_name != '' and project_folder != None :
+            # check projetc name validity
+            if self._isProjectNameValid(project_name) :
+                # check if project already exist
+                fullpath = os.path.join(project_folder, project_name)
+                if not self._isProjectExists(fullpath) :
+                    # all cons ok update project data
+                    self.project_data['project_name'] = project_name
+                    self.project_data['project_dir'] = project_folder
+                    self.assistant.set_page_complete(self,True)
+                    isProjectUpdated = True
+                else :
+                    # project with same name alreday exists
+                    msg = _("The project %s already exists !"%(fullpath)) 
+                    self.message_label.set_text(msg)
+            else :
+                # invalid projetc name
+                msg = _("%s isn't a valid project name. It should be a combination of alphanumeric and '_' characters "%project_name) 
+                self.message_label.set_text(msg)
+        
+        return isProjectUpdated
+
+
+
+            
+    def on_project_name_changed(self,widget):
+        """ indicate project name change. Set page complete if non blank text is set."""
+        l_project_name =  widget.get_text()
+        l_project_folder = self.fileChooser.get_filename()
+        self.UpdateProjectData(l_project_name, l_project_folder)
+ 
+    def on_dir_is_changed(self,widget) :
+        """ Call back for 'selection-changed' signal """
+        l_project_folder = widget.get_filename()
+        l_project_name =  self.entry_project_name.get_text()
+        self.UpdateProjectData(l_project_name, l_project_folder)
+
+ 
 
 
 class Page_matos(gtk.VBox) :
@@ -459,44 +482,20 @@ class Assistant_new_project(object) :
 
         self.assistant.show_all()
 
-        #
-        # defaul display  set entry project name
-        # 
-        self.p1.set_entry_project_name('luciole_project')
         
 
-
-
     def page_func(self,page_num) :
-        """ call back to verify the validity of the pages """
+        """ call back to know wcih  next page to load """
         page_out = page_num
-        if (self.verify_page_ok(page_num)) : 
-            if (page_out == 1 ) and  (self.project_data['hardtype'] != LCONST.WEBCAM) :
-                # if web cam selected go to page 2
-                # else go to page 3
-                page_out = 3
-            else :
-                page_out = page_out +1
+        if (page_out == 1 ) and  (self.project_data['hardtype'] != LCONST.WEBCAM) :
+            # if web cam selected go to page 2
+            # else go to page 3
+            page_out = 3
         else :
-            pageWidget = self.assistant.get_nth_page(page_num)
-            self.assistant.set_page_complete(pageWidget,False)
-            # if page verification failed return None to stay at the same page 
-            page_out = None
-            #self.assistant.set_current_page(0)
+            page_out = page_out +1
         return page_out
 
 
-    def verify_page_ok(self,num_page) :
-        """ verifies the pages validity """
-        state = False 
-        if (num_page == 0) :
-            # check data given as parameter
-            state = self.p1.verify_page(self.assistant)
-        else :
-            state = True
-        return state    
-    
-
     def on_quit(self,widget,event) :
         """ Quit button clicked """
         self.assistant.destroy()
