@@ -1,25 +1,25 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# -*- Mode: Python -*-
-# vi:si:ai:et:sw=4:sts=4:ts=4
+# -*- mode: python -*-
+# vim:si:ai:et:sw=4:sts=4:ts=4
 #
 #
-# Copyright Nicolas Bertrand (nico@inattendu.org), 2009
+# copyright nicolas bertrand (nico@inattendu.org), 2009-2010
 #
-# This file is part of Luciole.
+# this file is part of luciole.
 #
-#    Luciole is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
+#    luciole is free software: you can redistribute it and/or modify
+#    it under the terms of the gnu general public license as published by
+#    the free software foundation, either version 3 of the license, or
 #    (at your option) any later version.
 #
-#    Luciole is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
+#    luciole is distributed in the hope that it will be useful,
+#    but without any warranty; without even the implied warranty of
+#    merchantability or fitness for a particular purpose.  see the
+#    gnu general public license for more details.
 #
-#    You should have received a copy of the GNU General Public License
-#    along with Luciole.  If not, see <http://www.gnu.org/licenses/>.
+#    you should have received a copy of the gnu general public license
+#    along with luciole.  if not, see <http://www.gnu.org/licenses/>.
 #
 #
 import sys
@@ -36,7 +36,8 @@ import gettext
 import time
 import gc
 
-from .. import luciole_exceptions as M_EXCEP
+import logging 
+module_logger = logging.getLogger('luciole')
 
 import luciole_drawaera as GLD
 import montage_tree as GMT
@@ -45,10 +46,14 @@ import assistant_new_project as GLA
 import dialog as GDIALOG
 import open_project as GOF
 import luciole_export_window as GEXPORT
+import luciole_export_tool_window as GEXPORT_TOOL
+
 import open_project_widget as GOPEN
 import dialog_project_properties as GDIALOG_PROJ
 import dialog_preferences as GPREF
+
 from .. import luciole_constants as LCONST
+from .. import luciole_exceptions as LEXCEP
 
 import _version
 
@@ -109,7 +114,22 @@ class Gui_status_controller(object) :
 
 class Gui_controller(object):
     """ class handling interface with GUI/glade """
+    
 
+    #
+    # constants 
+    #
+    
+    # UI file specification
+    GUI_FILE = "luciole.glade"
+    
+    # main window name
+    GUI_MAIN_WINDOW = "window1"
+
+    
+    #
+    # properties
+    #
     def f_get_display(self) : return self.previsuDrawingArea
     display = property(f_get_display,None,None,"DrawArea widget for display")
    
@@ -129,8 +149,9 @@ class Gui_controller(object):
         self.PreviewObj.pixbufToDisplay = x
     pixbufToDisplay = property(f_get_pixbufToDisplay,f_set_pixbufToDisplay,None,"Pixbuf to display")
 
-    def f_get_ui_manager(self) : return self.builder.get_object('uimanager1')
-    ui_manager = property(f_get_ui_manager,None,None, 'The GUI UI manager')
+    def f_get_open_recent_menu(self) : 
+        return self.builder.get_object('menu_file_open_recent')
+    open_recent_menu = property(f_get_open_recent_menu,None,None, 'The Open recent menu')
 
     def f_get_status_progress_bar(self) : return Gui_status_controller(self._status_bar,self._status_progress_bar)
     status_progress_bar = property(f_get_status_progress_bar,None,None, 'The status progress bar')
@@ -144,16 +165,10 @@ class Gui_controller(object):
             self._snapshot_button.grab_focus()
     is_button_snapshot_sensitive = property(f_get_is_button_snapshot_sensitive,f_set_is_button_snapshot_sensitive,None, 'Snapshot button sensitivity')
 
-    def __init__(self, ctrl_obj) :
+    def _init_i18n(self):
+        """ Initialize all translation/i18n stuff """
+        self.locale_path = self.ctrl_obj.lcl_program['PO_DIR']
 
-        self.ctrl_obj = ctrl_obj
-        #Translation stuff
-        #Get the local directory since we are not installing anything
-        self.local_path = os.path.realpath(os.path.dirname(sys.argv[0]))
-        # set path for locale
-        if os.path.exists('../../share/luciole') :
-            self.local_path = os.path.normpath(os.path.join(self.local_path,'../../share/luciole'))
-        self.local_path = os.path.join(self.local_path,"po")
         # Init the list of languages to support
         langs = []
         #Check the default locale
@@ -164,6 +179,8 @@ class Gui_controller(object):
 
         # Now lets get all of the supported languages on the system
         language = os.environ.get('LANGUAGE', None)
+        msg = " language : ",language
+        self.logger.debug(msg)
         if (language):
             # langage comes back something like en_CA:en_US:en_GB:en
             # on linuxy systems, on Win32 it's nothing, so we need to
@@ -171,40 +188,65 @@ class Gui_controller(object):
             langs += language.split(":")
         # Now add on to the back of the list the translations that we
         # know that we have, our defaults"""
-        langs += ["en_US","fr"]
+        langs += ["en_US"]
+        
 
         # Now langs is a list of all of the languages that we are going
         # to try to use.  First we check the default, then what the system
         # told us, and finally the 'known' list
-
-        gettext.bindtextdomain(APP_NAME, self.local_path)
-        gettext.textdomain(APP_NAME)
-        # gtk glade translation  
-        gtk.glade.bindtextdomain(APP_NAME, self.local_path)
+        msg = "locale path", self.locale_path
+        self.logger.debug(msg)
+        
+        #
+        # nbd@ grape WARNING  : Why it is needed to do a bindtextdomain and textdomain 
+        # on glade as glade is no more use. Gtk.builder instead.
+        # if the bind on glade is not performed : the translation in glade files are not translated.
+        #
+        gtk.glade.bindtextdomain(APP_NAME, self.locale_path)
         gtk.glade.textdomain(APP_NAME)
+        gettext.bindtextdomain(APP_NAME, self.locale_path)
+        gettext.textdomain(APP_NAME)
+
+
+
         #print "langs %s de %s %s" % (APP_NAME,langs,self.local_path)
         # Get the language to use
-        self.lang = gettext.translation(APP_NAME, self.local_path
+        self.lang = gettext.translation(APP_NAME, self.locale_path
             , languages=langs, fallback = True)
         # Install the language, map _() (which we marked our
         # strings to translate with) to self.lang.gettext() which will
         # translate them."""
         global _
         _ = self.lang.gettext
+
+
+
+    def __init__(self, ctrl_obj) :
+        """ init GUI main obkect """
+        # init logger
+        self.logger = logging.getLogger('luciole')
+
+        self.ctrl_obj = ctrl_obj
         
-        guifile = "images/luciole.xml"
-        print "gui_controller : ",guifile
-        windowname = "window1"
-       
+        self._init_i18n()
+
+
         # GtkBuilder File load
         self.builder = gtk.Builder()
-        self.builder.add_from_file(guifile) 
-        self.window = self.builder.get_object(windowname)
+        self.builder.add_from_file( os.path.join(self.ctrl_obj.lcl_program['UI_DIR'],self.GUI_FILE) ) 
+
+        self.window = self.builder.get_object(self.GUI_MAIN_WINDOW)
         self.window.set_icon_from_file('images/luciole.png')
 
         self.window.set_title( "%s : %s"%(APP_NAME, 'No project' )  )     
         self.window.show()
 
+
+        # widgets for project init
+        self._init_project_buttons()
+        
+        # acquistion buttons initialization
+        self._init_acquistion_buttons()
         
         callbacks = {
                 'on_acquisition_button_toggled' :self.on_acquisition_button_toggled,
@@ -227,6 +269,7 @@ class Gui_controller(object):
                 'on_file_open_activate' : self.on_file_open_activate,
                 'on_file_import_activate' : self.on_file_import_activate,
                 'on_file_export_activate' : self.on_file_export_activate,                
+                'on_file_export_tool_activate' :self.on_file_export_tool_activate,
                 'on_file_quit_activate' : self.on_file_quit_activate,
                 'on_file_close_activate' : self.on_file_close_activate,
                 'on_view_project_activate' : self.on_view_project_activate,
@@ -238,7 +281,10 @@ class Gui_controller(object):
 
                 
         }
-        self.builder.connect_signals(callbacks) 
+        self.builder.connect_signals(callbacks)
+
+        #Force destroy event , even if in glade file, for exiting properly
+        self.window.connect("destroy",self.on_window_delete_event,"WM destroy")
         
         #preview window load
         self.previsuDrawingArea = self.builder.get_object("drawingarea1")
@@ -262,11 +308,7 @@ class Gui_controller(object):
         self._play_button = self.builder.get_object('button_play')
         self._play_pause_image = self.builder.get_object('image_play_pause')
 
-        # widgets for project init
-        self._init_project_buttons()
-        
-        # acquistion buttons initialization
-        self._init_acquistion_buttons()
+
         
 
         #status bar 
@@ -283,18 +325,21 @@ class Gui_controller(object):
         self._snapshot_button =  self.builder.get_object('snapshot_button')
         self._mixer_checkbutton =  self.builder.get_object('mixer_checkbutton')
         self._alpha_hscale = self.builder.get_object('alpha_hscale')
-        # focus disable on Hscalse does not work with glade forced here
+        # get default alpha value for mixer
+        self._alpha_hscale.set_value(LCONST.ALPHA_DEFAULT)
+        
+        # focus disable on Hscale does not work with glade forced here
         self._alpha_hscale.set_property('can-focus',False)
         self._alpha_hscale.set_property('can-default',False)
         
-        # load pixbuf for luciole activity in acquiistion button
+        # load pixbuf for luciole activity in acquisition button
         self._pxb_luciole_sleep = gtk.gdk.pixbuf_new_from_file("images/luciole-dodo.png")
         self._pxb_luciole_wakedup = gtk.gdk.pixbuf_new_from_file("images/luciole-eveillee.png")
         
         self.acquisition_widget_hide() #by default buttons are not active
       
     def acquisition_widget_hide(self) :
-        """ set acqusition buttons in non acquisition mode """
+        """ set acquisition buttons in non acquisition mode """
         self._acq_button_image.set_from_pixbuf(self._pxb_luciole_sleep)     # by default firefly is sleeping - no acquisition started
         
         self._snapshot_button.hide()            # snapshot button hide by default
@@ -312,7 +357,7 @@ class Gui_controller(object):
         self._acq_button_image.set_from_pixbuf(self._pxb_luciole_wakedup)
         self._snapshot_button.show()            # snapshot button hide by default
         self._mixer_checkbutton.show()            # mixer checkbox  hide by default
-        # if toggle butoon not acive : acivate it
+        # if toggle button not active : activate it
         if self._acq_button.get_active() == False :
             # the set_active function cause the toggle button signal emitted
             self._acq_button.set_active(True)
@@ -320,10 +365,15 @@ class Gui_controller(object):
     def _init_project_buttons(self) :
         """ initialisation of fpi buttons """
 
-        # get Hbox with acquistion widgets nas prent of this box  
+        # get Hbox with acquisition widgets nas prent of this box  
         self._hbox_acq = self.builder.get_object('hbox_acquisition')
         self._parent_hbox_acq = self._hbox_acq.get_parent()
 
+        # get View/menu widget
+        self._menu_view_project = self.builder.get_object('view_project')
+        # Not allow Menu --> View --> Project window
+        self._menu_view_project.set_sensitive(False)
+
         # create the open/new project widget
         self._open_project_wdg = GOPEN.Gui_open_project_widget(self.on_file_new_activate,self.on_file_open_activate)
         
@@ -338,34 +388,32 @@ class Gui_controller(object):
         self._fpi_hscale.set_property('can-focus',False)
         self._fpi_hscale.set_property('can-default',False)
         self._fpi_label = self.builder.get_object('label_fpi')
-        
+       
 
     def project_open_widgets(self) :
         """ When this function is called the project open/new buttons are dispalyed
-            The acquisistion buttons are hidden
+            The acquisition buttons are hidden
         """
         child = self._parent_hbox_acq.get_child()
         if  child != None :
             self._parent_hbox_acq.remove(child)
             self._parent_hbox_acq.add(self._open_project_wdg)
-
-            #self._acq_button.hide()
-            #self._fpi_hscale.hide()
-            #self._fpi_label.hide()
+        
+        # Not allow access to Prroject properies window
+        self._menu_view_project.set_sensitive(False)
 
     def project_acquistion_widgets(self) :
         """ When this function is called the acquisition widgets are displayed. 
             The open.new buttons are hidden
         """ 
+
         child = self._parent_hbox_acq.get_child()
         if  child != None :
             self._parent_hbox_acq.remove(child)
             self._parent_hbox_acq.add(self._hbox_acq)
             
-            #self._acq_button.show()
-            #self._fpi_hscale.show()
-            #self._fpi_label.show()
-
+        # Allow access to Prroject properies window
+        self._menu_view_project.set_sensitive(True)
 
 
 
@@ -404,15 +452,15 @@ class Gui_controller(object):
             
             l_isOk = True
         else :
-            # raise errror
-            print " unable to find treeview capture "
+            # raise error
+            lerr =  " unable to find treeview capture "
+            raise LEXCEP.LucioException, lerr
         
         wdg_tvcapture =  self.wdg_montage_default
         
         if ( l_isOk == True ) and (wdg_tvcapture != None) :
             #get parent and remove treeview
             wdg_tvparent =  wdg_tvcapture.get_parent()
-            print wdg_tvcapture.get_name() , " as father : ",wdg_tvparent.get_name()
             wdg_tvparent.remove(wdg_tvcapture)
             
             # Create capture treeview
@@ -426,13 +474,14 @@ class Gui_controller(object):
             l_isOk = True
         else :
             # raise errror
-            print " unable to find treeview montage "
+            lerr =  " unable to find treeview capture "
+            raise LEXCEP.LucioException, lerr
+
             l_isOk = False
 
     def clear_treeviews(self):
         """ clear both capture and montage treeviews """
         self.clear_treeviews_ctr = self.clear_treeviews_ctr +1 
-        print " ENTREING : clear_treeviews : ", self.clear_treeviews_ctr
         
         wdg_tvcapture = self._tv_capture
         if wdg_tvcapture != None :
@@ -489,7 +538,6 @@ class Gui_controller(object):
     def open_project(self) :
         """ launch the open project window """
         filename = GOF.Open_file.open()
-        print " filename  : ", filename
         return filename
      
     def set_programbar(self,text, isModified = False) :
@@ -518,6 +566,11 @@ class Gui_controller(object):
         """ Display export window """
         self._exportObj.gui_export(project_data)
 
+    def export_tool_dialog(self,project_data) :
+        """ Display export tool window """
+        X = GEXPORT_TOOL.dialog_export_file(project=project_data)
+        X.run()
+
     def update_play_button(self,is_active = False) :
         """ 
         update pressed state and icon image for play pause
@@ -682,6 +735,10 @@ class Gui_controller(object):
         """file export activate """
         self.ctrl_obj.export()
 
+    def on_file_export_tool_activate(self,widget):
+        """file export activate """
+        self.ctrl_obj.export_tool()
+
     def on_file_quit_activate(self,widget):
         """ file quit actovated"""
         self.ctrl_obj.quit() 
