@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # -*- Mode: Python -*-
-# vi:si:ai:et:sw=4:sts=4:ts=4
+# vim:si:ai:et:sw=4:sts=4:ts=4
 #
 #
-# Copyright Nicolas Bertrand (nico@inattendu.org), 2009
+# Copyright Nicolas Bertrand (nico@inattendu.org), 2009-2010
 #
 # This file is part of Luciole.
 #
@@ -26,18 +26,22 @@
 luciole_controller.py :
    Software controller manage interactions between elements 
 """
+import logging 
+module_logger = logging.getLogger('luciole')
+
+
 import luciole_tools as LT
 import luciole_project as LP
 import luciole_image as LI
 import luciole_constants as LCONST
 import luciole_exceptions as L_EXCEP
-import luciole_player as LPLAYER
 import luciole_conf as LCONF
 import luciole_manage_recent as LRECENT
-import luciole_gstreamer_play_sound as LSOUND
 import controller.controller_import as LC_IMPORT
 import controller.controller_load_project as LC_LOAD
+import luciole_player as LPLAYER
 
+from lcl_gst import lcl_gst_play_sound as LSOUND
 
 import gui as LTK
 import time
@@ -57,6 +61,12 @@ class Luciole_controller(object) :
    
     def __init__(self) :
         """ controller init """
+        # init logger
+        self.logger = logging.getLogger('luciole')
+        self.lcl_program = {}
+        
+        self._set_program_path()
+
         # init Luciole conf obj
         self.conf_obj =  LCONF.LucioleConf()
         
@@ -78,13 +88,13 @@ class Luciole_controller(object) :
         self.recent_project_list = self.conf_obj.conf_options["LastProjects"]
         
         # init the recent project manager
-        self.recent_project_obj = LRECENT.luciole_recent(self.recent_project_list, self.gui.ui_manager, self.open_project ,self.conf_obj)   
+        self.recent_project_obj = LRECENT.luciole_recent(self.recent_project_list, self.gui, self.open_project ,self.conf_obj)   
 
         # get status bar
         self.status_bar = self.gui.status_progress_bar
 
         #init sound player
-        self.sound_player = LSOUND.luciole_gstreamer_sound('./sounds/camera.ogg')
+        self.sound_player = LSOUND.Lcl_gst_sound('./sounds/camera.ogg')
 
         self.acq_obj = None
         self.rush_obj = None
@@ -116,10 +126,6 @@ class Luciole_controller(object) :
         project_dico_data = LP.project_dico() 
         for k,v in project_data.iteritems() :
             project_dico_data[k] = project_data[k]
-            #convert webcam_data as str values to be coherent with load of webcam data from a file
-            if k == 'webcam_data' : 
-                for w_k in project_dico_data[k].keys() :
-                    project_dico_data[k][w_k] = "%s"%project_dico_data[k][w_k]
         self.project = project_dico_data
 
         # 2. create project ( folder structure ,etc ...)
@@ -134,16 +140,27 @@ class Luciole_controller(object) :
         if project_path == None  :
             # if no project_path as paramter open dialog to choose one
             project_path = self.gui.open_project()
-        
         if self.project != None : 
             # if a project is loaded close it
-            print """ DEBUG : Close project Before """ 
+            self.logger.debug("Close a project Before loading a new one") 
             self.close()
+       
+        # checj if a projetct path was entered
+        if project_path != None:
+            try :
+                (is_valid,self.project) = self.project_ctrller.open(project_path)
+            except L_EXCEP.LucioException,err :
+                raise L_EXCEP.LucioException,err
+        
+            # webcam data are not valid
+            if is_valid == False :
+                msg = _(" Webcam data not valid in project. Please restart webcam detection")
+                LTK.Dialog.ErrorMessage(self.gui.window, msg)
 
-        self.project = self.project_ctrller.open(project_path)
 
-        # 3. load project in application
-        self.__load_project_in_app()
+            #load project in application
+            self.__load_project_in_app()
+
 
     def save_project(self):
         """ save the current project """
@@ -162,7 +179,6 @@ class Luciole_controller(object) :
         if self.project != None :
             #launch dir chooser
             l_dir = self.gui.dir_chooser_dialog()
-            print l_dir
             if l_dir != None :
                 # launch project save as
                 self.project_ctrller.save_as(l_dir,self.project)
@@ -205,7 +221,8 @@ class Luciole_controller(object) :
             # 1. copy it to rush dir and rename it
             l_rush_imagename = self.__move_capture_to_rush_folder() 
         except L_EXCEP.LucioException,err :
-            print " DEBUG ERROR in image capture :", err
+            err_msg = " ERROR in image capture :", err
+            raise L_EXCEP.LucioException,err_msg
         else : 
             #2.append it to rush and capture obj
             self.__append_image_to_project(l_rush_imagename)
@@ -258,10 +275,17 @@ class Luciole_controller(object) :
         if self.project != None :
             self.gui.export_dialog(self.project)
         else :
-            # nbd@grape to transform as error message
             msg = _("Nothing to export. No project loaded")
             LTK.Dialog.ErrorMessage(self.gui.window, msg)
-
+    
+    def export_tool(self) :
+        """ Manage tool exports """
+        if self.project != None :
+            self.gui.export_tool_dialog(self.project)
+        else :
+            msg = _("Nothing to export. No project loaded")
+            LTK.Dialog.ErrorMessage(self.gui.window, msg)
+ 
     def play(self,index_chrono) :
         """ play video """
         # Test if project exists
@@ -277,7 +301,9 @@ class Luciole_controller(object) :
                                             )
                 except L_EXCEP.LucioException,err :
                     # nbd@grape specify action to do err message or raise exception ?
-                    print _("Imposible to initialize player.")
+                    err_msg = "Imposible to initialize player.\n", err
+                    raise L_EXCEP.LucioException,err_msg
+                    
                 else :
                     # disable imager and acquirer
                     self._set_imager(False)
@@ -345,11 +371,14 @@ class Luciole_controller(object) :
                 self.project['is_modified'] = LCONST.PROJECT_MODIFIED
                 self.gui.set_programbar(self.project['project_name'],True)
             else :
-                #nbd@grape :raise Error/Exception 
-                print "key %s not in project "%project_key      
+                #raise Error/Exception 
+                err =  "key %s not in project "%project_key 
+                raise L_EXCEP.LucioException,err
+
         else :
-            #nbd@grape :raise Error/Exception 
-            print " Project not loaded "
+            # raise Error/Exception 
+            err = " Project not loaded "
+            raise L_EXCEP.LucioException,err
 
     def close(self) :
         """ Close current project """
@@ -411,7 +440,7 @@ class Luciole_controller(object) :
                         self._set_player(False)     # set player as inactive 
                     else :
                         #acquisition yet started
-                        print "acquisition Yet started : Not expected event "
+                        self.logger.debug("acquisition Yet started : Not expected event ")
                         # State not normal - stop acquirer
                         self._set_acquirer(False)   # stop acquirer
                         self._set_imager(True)      # allow imager    
@@ -559,6 +588,12 @@ class Luciole_controller(object) :
     def project_properties(self) :
         """ request Display of project properties """ 
         if self.project != None :
+            if self._acquirer_active == True :
+                self.status_bar.display_message(_('No Acquistion'))
+                self._set_acquirer(False)   # deactivate acquirer 
+                self._set_imager(True)      # allow imager 
+                self._set_player(False)     # Player not activated (robsutness)
+ 
             self.gui.display_project_properties(self.project,self._cb_project_change)
              
        
@@ -621,12 +656,12 @@ class Luciole_controller(object) :
         """ load treview, pepare acquiistion rush list , etc .."""
         self.time = time.time()
         if self.project != None :
-            print "---------------------------------------------------------------------"
-            print "TEST Luciole_controller project info: "
-            print "---------------------------------------------------------------------"
+            self.logger.debug("---------------------------------------------------------------------")
+            self.logger.debug("Luciole_controller project info: ")
+            self.logger.debug("---------------------------------------------------------------------")
             for k,v in self.project.iteritems() :
-                print "**%s** : %s "%(k,v)
-            print "---------------------------------------------------------------------"
+                self.logger.debug("**%s** : %s "%(k,v))
+            self.logger.debug( "---------------------------------------------------------------------")
 
             # Initilaisation of rush ogbj is threaded because its take a while (generation of images pixbufs)
             # When rush load is finish : __on_rush_finish is called 
@@ -645,7 +680,7 @@ class Luciole_controller(object) :
             # set project as not modified 
             self.project['is_modified'] = LCONST.PROJECT_NOT_MODIFIED
 
-            print ' DEBUG  load time = %s'%( time.time() - self.time )
+            self.logger.debug('load time = %s'%( time.time() - self.time ))
         else :
             msg =  _("Failed to load project ")
             LTK.Dialog.ErrorMessage(self.gui.window, msg)
@@ -702,9 +737,11 @@ class Luciole_controller(object) :
         
         self.gui.append_capture(l_rush_image)  
 
-        # 3. if onion skin active update image
-        if self.acq_obj.IsOnionSkinActive == True :
-            self.acq_obj.Image2Mix = l_rush_image.path 
+        
+        # always update the image 2 mix, even if mixer is not active
+        # used to memorize the last capture 
+ 
+        self.acq_obj.Image2Mix = l_rush_image.path 
     
      
     def _stop_acquisition(self):
@@ -746,4 +783,17 @@ class Luciole_controller(object) :
         if (type(is_active) == bool) and (self._mixer_active != is_active) :
             self._mixer_active = is_active
 
+    def _set_program_path(self) :
+        """
+         set some program path usefull for other luciole objects
+        """
+        
+        # get execution path
+        BASE_DIR = os.path.realpath('.')
+        self.lcl_program['BASE_DIR'] = BASE_DIR
+        self.lcl_program['THEMES_DIR'] = os.path.join(BASE_DIR,'themes')
+        self.lcl_program['UI_DIR'] = os.path.join(BASE_DIR,'ui')
+        self.lcl_program['PO_DIR'] = os.path.join(BASE_DIR,'po')
+
+
 
