@@ -109,9 +109,9 @@ class project_controller(object) :
         """ open an existing project """
         l_project = project_dico()
         if os.path.isfile(project_file_path) :
-            #create  projetc dico
+            #create  project dico
             l_project['project_path'] = project_file_path
-
+            l_project['project_dir'] = os.path.split(project_file_path)[0]
             #parse XML project file
             try :
                 self.__project_xml = ET.parse(project_file_path)
@@ -124,16 +124,23 @@ class project_controller(object) :
                 l_project['is_modified'] = LCONST.PROJECT_NOT_MODIFIED 
                 # tmp dir nit in xml file but needed
                 l_project['tmp_dir'] = LCONST.TMP_DIR
-                l_project = self.__scan_project_file(l_project)
-                
-                if l_project != None : 
+                try : 
+                    (l_is_valid, l_project_changed, l_project) = self.__scan_project_file(l_project)
+                except LEXCEP.LucioException, err :
+                    raise LEXCEP.LucioException, err
+                else :
                     self.__project_loaded = True
+                    if l_project_changed == True :
+                        # save to file loaded project due to project cange
+                        # outside application 
+                        self.save(l_project)
+                        
         else:
             # exception handling
             lerr =  " invalid file name : ",project_file_path
             raise LEXCEP.LucioException, lerr
             l_project = None
-        return l_project
+        return (l_is_valid, l_project)
 
     def save(self,p_project_dico ) :
         """ save a project to XML file """
@@ -186,9 +193,16 @@ class project_controller(object) :
 
     def __scan_project_file(self,p_project) :
         """ scan xml project file """
+        # by default a project is valid : 
+        # validity is only available with WEBCAM hardtype 
+        is_valid = True 
+        l_project_changed = False
+
         # get path and dir data
         p_project['project_name'] = self.__project_xml.findtext("metas/projectName").strip()
-        p_project['project_dir'] = self.__project_xml.findtext("metas/projectPath").strip()
+        # check if path cahnged 
+        if p_project['project_dir'] != self.__project_xml.findtext("metas/projectPath").strip() :
+            l_project_changed = True 
         p_project['export_dir'] = self.__project_xml.findtext("metas/export_dir").strip()
         p_project['rush_dir'] = self.__project_xml.findtext("metas/rush_dir").strip()
         # tmp dir nit in xml file but needed
@@ -202,10 +216,7 @@ class project_controller(object) :
         elem=self.__project_xml.find("metas/hardtype")
         p_project['hardtype'] = int(elem.attrib["id"])
         
-        # by default a project is valid : 
-        # validity is only available with WEBCAM hardtype 
-        is_valid = True 
-        
+       
         # get webcam data
         if p_project['hardtype'] == LCONST.WEBCAM :
             # loop on webcam datas
@@ -253,7 +264,7 @@ class project_controller(object) :
       
         p_project = self.__check_rush_images(p_project)
         
-        return (is_valid,p_project)
+        return (is_valid, l_project_changed, p_project)
 
 
     def __scanImages(self,p_type) :
