@@ -42,12 +42,11 @@ os.chdir('po')
 if command == 'compile':
     files = glob.glob('*.po')
     for f in files:
-        print "%s"%f
+        print "working on language %s"%f
         l = os.path.splitext(f)
-        os.system('mkdir -p -m 0777 %s/LC_MESSAGES' % l[0][8:])
-
+        os.system('mkdir -p -m 0777 %s/LC_MESSAGES' % l[0])
         print "Generating translation for %s locale" % l[0]
-        os.system('msgmerge -o - %s luciole.pot | msgfmt -c -o %s/LC_MESSAGES/luciole.mo -' % (f, l[0][8:]))
+        os.system('msgmerge -o - %s luciole.pot | msgfmt -c -o %s/LC_MESSAGES/luciole.mo -' % (f, l[0]))
 elif command == 'update_po' :
     os.system('intltool-update --pot --gettext-package=luciole --verbose ')
     files = glob.glob('*.po')
